@@ -4,7 +4,7 @@ use warnings;
 no warnings qw(redefine);
 package RT::Extension::ConditionalCustomFields;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =encoding utf8
 
@@ -98,7 +98,7 @@ sub SetConditionedBy {
             unless     $cf_value->id
                     && $cf_value->CustomFieldObj
                     && $cf_value->CustomFieldObj->id
-                    && $cf_value->CustomFieldObj->CurrentUserCanSee;
+                    && $cf_value->CustomFieldObj->CurrentUserHasRight('SeeCustomField');
         ($ret, $msg) = $self->SetAttribute(
             Name    => 'ConditionedBy',
             Content => $value,
@@ -342,11 +342,11 @@ L<https://github.com/gibus/RT-Extension-ConditionalCustomFields>
 
 All bugs should be reported via email to
 
-    L<bug-RT-Extension-ConditionalCustomFields@rt.cpan.org|mailto:bug-RT-Extension-ConditionalCustomFields@rt.cpan.org>
+L<bug-RT-Extension-ConditionalCustomFields@rt.cpan.org|mailto:bug-RT-Extension-ConditionalCustomFields@rt.cpan.org>
 
 or via the web at
 
-    L<rt.cpan.org|http://rt.cpan.org/Public/Dist/Display.html?Name=RT-Extension-ConditionalCustomFields>.
+L<rt.cpan.org|http://rt.cpan.org/Public/Dist/Display.html?Name=RT-Extension-ConditionalCustomFields>.
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -354,7 +354,7 @@ This software is Copyright (c) 2017 by Gérald Sédrati-Dinet, Easter-Eggs
 
 This is free software, licensed under:
 
-  The GNU General Public License, Version 3, June 2007
+The GNU General Public License, Version 3, June 2007
 
 =cut
 
